// ===========================================================================
// CONTENT  : CLASS NamedCloseable
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 14/05/2015
// HISTORY  :
//  14/05/2015  mdu  CREATED
//
// Copyright (c) 2015, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.file;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.io.Closeable;

/**
 * An abstract implementation to decorate a Closeable with a name.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
abstract public class NamedCloseable implements Closeable
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private String name;
  
  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  protected NamedCloseable()
  {
    super();
  } // NamedCloseable()

  protected NamedCloseable(String name)
  {
    this();
    this.setName(name);
  } // NamedCloseable()
  
  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  public String getName()
  {
    return this.name;
  }
  
  /**
   * Sets the name of the associated closeable.
   * 
   * @param name The new name (must not be null).
   * @throws IllegalArgumentException If the given name is null.
   */
  public void setName(String name)
  {
    if (name == null)
    {
      throw new IllegalArgumentException("The provided name is null!");
    }
    this.name = name;
  }
  
  /**
   * Closes the underlying closeable catching any exception.
   */
  @Override
  public void close()
  {
    FileUtil.current().close(this.getCloseable());
  }
  
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  /**
   * Returns the closeable that is associated with the name defined in this class.
   */
  abstract protected Closeable getCloseable();
  
} // class NamedCloseable
