// ===========================================================================
// CONTENT  : ABSTRACT CLASS AbstractSubContainer
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 01/11/2015
// HISTORY  :
//  01/11/2015  mdu  CREATED
//
// Copyright (c) 2015, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.file.cfiles;

// ===========================================================================
// IMPORTS
// ===========================================================================

/**
 * General implementation of a sub container that has a parent container and
 * contains 0-n items. 
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
abstract public class AbstractSubContainer extends AbstractContainer implements ISubContainer
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
  public static final String NAME_SEPARATOR = "/";

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private IContainer container;

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  public AbstractSubContainer(String name)
  {
    super(name);
  }

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  @Override
  public IContainer getContainer()
  {
    return this.container;
  }
  
  @Override
  public void setContainer(IContainer container)
  {
    this.container = container;
  }
  
  @Override
  public void appendNameTo(StringBuilder builder)
  {
    if (this.hasContainer())
    {
      this.getContainer().appendNameTo(builder);
      builder.append(this.getNameSeparator());
    }
    super.appendNameTo(builder);
  }

  /**
   * Takes the parent container into account!
   */
  @Override
  public int hashCode()
  {
    int hash = this.hasContainer() ? this.getContainer().hashCode() : 0; 
    return hash ^ this.basicHashCode();
  }
  
  /**
   * Takes the parent container into account!
   */
  @Override
  public boolean equals(Object obj)
  {
    ISubContainer other;
    
    if (this.basicEquals(obj))
    {
      if (this.hasContainer())
      {
        other = (ISubContainer)obj;
        return this.getContainer().equals(other.getContainer());
      }
    }
    return false;
  }

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  protected boolean hasContainer()
  {
    return this.getContainer() != null;
  }
  
  protected String getNameSeparator() 
  {
    return NAME_SEPARATOR;
  }
}
