// ===========================================================================
// CONTENT  : INTERFACE IContainer
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 01/11/2015
// HISTORY  :
//  01/11/2015  mdu  CREATED
//
// Copyright (c) 2015, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.file.cfiles ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.util.List;

import org.pfsw.bif.lifecycle.IReleasable;

/**
 * A container that holds multiple items.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public interface IContainer extends INamedElement, IReleasable
{
  /**
   * Adds one or more items to this container.
   * That implies that the container sets itself as the container of the item.
   * 
   * @param items One or more items to be added.
   */
  public void addItem(IItem... items);
  
  /**
   * Removes one or more items from this container.
   * If a given item is not in the container, it will be silently ignored.
   * Each item removed will also be detached from this container by calling
   * its {@link IItem#release()} method.
   * 
   * @param items One or more items to be removed.
   */
  public void removeItem(IItem... items);
  
  /**
   * Returns all items of this container. This will always
   * be a copy of any internal list representation. That is, manipulating
   * the returned list has no impact on the container's list of elements.
   * 
   * @return A list with all items (maybe empty). Never null.
   */
  public List<IItem> getItems();
  
  /**
   * Returns the number of currently contained items;
   * 
   * @return The number of items in the range of 0 - MAX_INT.
   */
  public int size();
  
  /**
   * Returns whether or not this container contains items.
   * @return true if the container contains at least one item.
   */
  public boolean isEmpty();
}