// ===========================================================================
// CONTENT  : INTERFACE IItem
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 01/11/2015
// HISTORY  :
//  01/11/2015  mdu  CREATED
//
// Copyright (c) 2015, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.file.cfiles ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pfsw.bif.lifecycle.IReleasable;

/**
 * An item is always associated to a container. 
 * To detach the container from an item the {@link #release()} method must be used.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public interface IItem extends INamedElement, IReleasable
{   
  /**
   * Returns the container this item is associated with.
   * 
   * @return The container or null if the item has been detached from its container.
   */
  public IContainer getContainer();
  
  /**
   * Sets the container of this item. 
   * Setting the container to null is not allowed. Use {@link #release()} instead. 
   * 
   * @param container The container to associate the item with (not null).
   * @throws IllegalArgumentException If the given container is null.
   */
  public void setContainer(IContainer container);
}