// ===========================================================================
// CONTENT  : CLASS BasePluginRegistration
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 23/11/2014
// HISTORY  :
//  23/11/2014  mdu  CREATED
//
// Copyright (c) 2014, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.plugin;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.util.HashMap;
import java.util.Map;

/**
 * An abstract implementation of the PluginRegistration interface that can be 
 * extended and filled with the relevant data by overriding the {@link #initialize()}
 * method.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
abstract public class BasePluginRegistration implements PluginRegistration
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private final Map<String, Class<?>> registrationMap = new HashMap<String, Class<?>>();

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  public BasePluginRegistration()
  {
    super();
    this.initialize();
  } // BasePluginRegistration() 

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  @Override
  public Map<String, Class<?>> getClassesToRegister()
  {
    HashMap<String,Class<?>> map;
    
    // Return a copy
    map = new HashMap<String, Class<?>>(this.getRegistrationMap());
    return map;
  } // getClassesToRegister() 
  
  // -------------------------------------------------------------------------
  
  /**
   * Add an entry to the registration data. If another entry with the same key 
   * exists it will be replaced. 
   */
  public void add(String key, Class<?> type)
  {
    if ((key != null) && (type != null))
    {      
      this.getRegistrationMap().put(key, type);
    }
  } // add() 
  
  // -------------------------------------------------------------------------
  
  /**
   * Will be called from the constructor to fill the internal map with values.
   * This method should be overridden by subclasses.
   */
  public void initialize() 
  {
    // Nothing here
  } // initialize()
  
  // -------------------------------------------------------------------------

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  protected Map<String, Class<?>> getRegistrationMap()
  {
    return this.registrationMap;
  } // getRegistrationMap() 
  
  // -------------------------------------------------------------------------
  
} // class BasePluginRegistration 
