// ===========================================================================
// CONTENT  : CLASS ElementNameFilter
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.1 - 11/06/2016
// HISTORY  :
//  19/01/2014  mdu  CREATED
//  11/06/2016  mdu   changed -> from StringFilter to IStringFilter
//
// Copyright (c) 2014-2016, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.six;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pfsw.bif.text.IStringFilter;
import org.pfsw.text.StringPattern;

/**
 * Can be used to find elements that match a particular element name or name pattern.
 *
 * @author Manfred Duchrow
 * @version 1.1
 */
public class ElementNameFilter extends AElementFilter
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private IStringFilter tagNameFilter;

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  public ElementNameFilter(IStringFilter tagNameFilter)
  {
    super();
    this.tagNameFilter = tagNameFilter;
  } // ElementNameFilter() 
  
  // -------------------------------------------------------------------------
  
  /**
   * Creates a filter for the given name or name pattern (if "?" or "*" used).
   * 
   * @param tagName The name or name pattern (must not be null).
   */
  public ElementNameFilter(String tagName)
  {
    this(new StringPattern(tagName));
  } // ElementNameFilter() 
  
  // -------------------------------------------------------------------------

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  @Override
  protected boolean matchesElement(Element element)
  {
    if (!this.getTagNameFilter().matches(element.getName()))
    {
      return false;
    }
    return true;
  } // matchesElement()
  
  // -------------------------------------------------------------------------
  
  protected IStringFilter getTagNameFilter()
  {
    return tagNameFilter;
  } // getTagNameFilter()
  
  // -------------------------------------------------------------------------
  
} // class ElementNameFilter 
