// ===========================================================================
// CONTENT  : CLASS LoggerProvider
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.1 - 22/06/2014
// HISTORY  :
//  29/06/2002  duma  CREATED
//  22/06/2014  mdu   changed --> Using now LoggerFactory
//
// Copyright (c) 2002-2014, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.six;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pfsw.logging.Logger;
import org.pfsw.logging.LoggerFactoryProvider;
import org.pfsw.logging.nil.NilLogger;

/**
 * This is the central access point for the package's logger.
 * Replacing the logger here means that all classes in this package
 * will use the new logger for further output.
 *
 * @author Manfred Duchrow
 * @version 1.1
 */
public class LoggerProvider
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
  public static final String LOGGER_NAME = "org.pfsw.six";

  // =========================================================================
  // CLASS VARIABLES
  // =========================================================================
  private static Logger logger = LoggerFactoryProvider.getLoggerFactory().getLogger(LOGGER_NAME);
  private static boolean isLoggingSupressed = false;

  // =========================================================================
  // PUBLIC CLASS METHODS
  // =========================================================================
  /**
   * Returns the current logger used by this component to report
   * errors and exceptions. 
   */
  public static Logger getLogger()
  {
    return logger;
  } // getLogger() 

  // -------------------------------------------------------------------------

  /**
   * Replace the logger by another one. A value of null installs
   * the prg.pf.logging.NilLogger.
   */
  public static void setLogger(Logger newLogger)
  {
    if (newLogger == null)
    {
      logger = new NilLogger();
    }
    else
    {
      isLoggingSupressed = false;
      logger = newLogger;
    }
  } // setLogger() 

  // -------------------------------------------------------------------------

  /**
   * Supress all logging. That might cause the component to rather throw
   * exceptions than just log some error messages.
   */
  public static void supressLogging()
  {
    isLoggingSupressed = true;
    setLogger(null);
  } // supressLogging()

  // -------------------------------------------------------------------------

  /**
   * Returns true if currently nothing will be logged
   */
  public static boolean isLoggingSupressed()
  {
    return isLoggingSupressed;
  } // isLoggingSupressed() 

  // -------------------------------------------------------------------------

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  private LoggerProvider()
  {
    super();
  } // LoggerProvider() 

  // -------------------------------------------------------------------------

} // class LoggerProvider 
