// ===========================================================================
// CONTENT  : CLASS NamedText
// AUTHOR   : Manfred Duchrow
// VERSION  : 2.1 - 26/01/2017
// HISTORY  :
//  14/07/2002  duma  CREATED
//	11/02/2004	duma	added		-->	copy()
//	16/07/2004	duma	added		-->	copyNamedText()
//	27/03/2010	mdu		changed	-->	to generic type support
//  26/01/2017  mdu   added   --> implements IMutableStringPair
//
// Copyright (c) 2002-2017, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.util;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pfsw.bif.text.IMutableStringPair;

/**
 * An association of a name string and a text value.
 * Both, name and value can never be null!
 * <br>
 * Access to key and value is provided by
 * <ul>
 *   <li>name()
 *   <li>name( newName )
 *   <li>text()
 *   <li>text( newText )
 * </ul>
 *
 * @author Manfred Duchrow
 * @version 2.1
 */
public class NamedText extends NamedValue<String> implements IMutableStringPair
{
  private static final long serialVersionUID = -6457723232212562385L;

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with the given name and value.
   * Both, name and value must not be null. If any of them is null it will
   * be automatically translated to an empty String ("").
   */
  public NamedText(String name, String text)
  {
    super((name == null) ? "" : name, (text == null) ? "" : text);
  }

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  /**
   * Sets the text (value) of the association.
   * 
   * @param newText The new text (a null value will be ignored)
   */
  @Override
  public void value(String newText)
  {
    if (newText != null)
    {
      super.value(newText);
    }
  } 

  /**
   * Sets the text (value) of the association.
   * 
   * @param newText The new text (a null value will be ignored)
   */
  public void text(String newText)
  {
    this.value(newText);
  }

  /**
   * Returns the text (value) of the association.
   */
  public String text()
  {
    return this.value();
  }

  /**
   * Returns a copy of this object
   */
  public NamedText copy()
  {
    return this.copyNamedText();
  }  

  /**
   * Returns a copy of this object
   */
  public NamedText copyNamedText()
  {
    NamedText copy;

    copy = new NamedText(this.name(), this.text());
    return copy;
  } 

  @Override
  public String getString1()
  {
    return this.name();
  }
  
  @Override
  public void setString1(String string)
  {
    this.name(string);
  }
  
  @Override
  public String getString2()
  {
    return this.text();
  }
  
  @Override
  public void setString2(String string)
  {
    this.text(string);
  }
  
  @Override
  public String[] asArray()
  {
    return new String[] { this.getString1(), this.getString2() };
  }
  
  @Override
  public String asString(String separator)
  {
    return this.getString1() + separator + this.getString2();
  }
} 
